@@ -9,7 +9,7 @@ constitutes the alternation operator, which is used whenever either one of the
 provided patterns can be matched.
 
 Classes & methods
-===========================================
+-------------------------------------------
 
 Below are listed all classes within :py:mod:`pregex.operators`
 along with any possible methods they may possess.
@@ -24,7 +24,7 @@ class __Operator(_pre.Pregex):
         the patterns to which the operator is to be applied.
     :param (tuple[Pregex | str] => str) transform: A `transform` function for the provided pattern.
 
-    :raises LessThanTwoArgumentsException: Less than two arguments are provided.
+    :raises NotEnoughArgumentsException: Less than two arguments are provided.
     '''
     def __init__(self, pres: tuple[_pre.Pregex or str], transform) -> _pre.Pregex:
         '''
@@ -34,12 +34,13 @@ class __Operator(_pre.Pregex):
             the patterns to which the operator is to be applied.
         :param (tuple[Pregex | str] => str) transform: A `transform` function for the provided pattern.
 
-        :raises LessThanTwoArgumentsException: Less than two arguments are provided.
+        :raises NotEnoughArgumentsException: Less than two arguments are provided.
         '''
         if len(pres) < 2:
-            raise _ex.LessThanTwoArgumentsException()
-        result = __class__._to_pregex(pres[0])
-        for pre in pres[1:]:
+            message = "At least two requirements are required."
+            raise _ex.NotEnoughArgumentsException(message)
+        result =_pre.Empty()
+        for pre in pres:
             result = _pre.Pregex(transform(result, __class__._to_pregex(pre)), escape=False)
         super().__init__(str(result), escape=False)
 
@@ -50,7 +51,7 @@ class Concat(__Operator):
 
     :param Pregex | str \*pres: Two or more patterns that are to be concatenated.
 
-    :raises LessThanTwoArgumentsException: Less than two arguments are provided.
+    :raises NotEnoughArgumentsException: Less than two arguments are provided.
     '''
 
     def __init__(self, *pres: _pre.Pregex or str) -> _pre.Pregex:
@@ -59,7 +60,7 @@ class Concat(__Operator):
 
         :param Pregex | str \*pres: Two or more patterns that are to be concatenated.
 
-        :raises LessThanTwoArgumentsException: Less than two arguments are provided.
+        :raises NotEnoughArgumentsException: Less than two arguments are provided.
         '''
         super().__init__(pres, lambda pre1, pre2: pre1._concat(pre2))
 
@@ -71,7 +72,7 @@ class Either(__Operator):
     :param Pregex | str \*pres: Two or more patterns that constitute the \
         operator's alternatives.
 
-    :raises LessThanTwoArgumentsException: Less than two arguments are provided.
+    :raises NotEnoughArgumentsException: Less than two arguments are provided.
 
     :note: One should be aware that ``Either`` is eager, meaning that the regex engine will \
         stop the moment it matches either one of the alternatives, starting from \
@@ -85,7 +86,7 @@ class Either(__Operator):
         :param Pregex | str \*pres: Two or more patterns that constitute the \
             operator's alternatives.
 
-        :raises LessThanTwoArgumentsException: Less than two arguments are provided.
+        :raises NotEnoughArgumentsException: Less than two arguments are provided.
 
         :note: One should be aware that ``Either`` is eager, meaning that the regex engine will \
             stop the moment it matches either one of the alternatives, starting from \
